Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'bundles/org.eclipse.osgi.services/src/org/osgi/service/http/runtime/dto/ServletContextDTO.java')
-rw-r--r--bundles/org.eclipse.osgi.services/src/org/osgi/service/http/runtime/dto/ServletContextDTO.java41
1 files changed, 23 insertions, 18 deletions
diff --git a/bundles/org.eclipse.osgi.services/src/org/osgi/service/http/runtime/dto/ServletContextDTO.java b/bundles/org.eclipse.osgi.services/src/org/osgi/service/http/runtime/dto/ServletContextDTO.java
index d4d067f5b..668a57ac5 100644
--- a/bundles/org.eclipse.osgi.services/src/org/osgi/service/http/runtime/dto/ServletContextDTO.java
+++ b/bundles/org.eclipse.osgi.services/src/org/osgi/service/http/runtime/dto/ServletContextDTO.java
@@ -20,8 +20,9 @@ import java.util.Map;
import org.osgi.dto.DTO;
/**
- * Represents a {@code javax.servlet.ServletContext} created for used servlets,
- * resources, servlet filters, and listeners. The servlet context is backed by a
+ * Represents a {@code javax.servlet.ServletContext} created for servlets,
+ * resources, servlet Filters, and listeners associated with that servlet
+ * context. The Servlet Context is usually backed by a
* {@link org.osgi.service.http.context.ServletContextHelper} service.
*
* @NotThreadSafe
@@ -29,12 +30,12 @@ import org.osgi.dto.DTO;
*/
public class ServletContextDTO extends DTO {
/**
- * The names of the HTTP context.
+ * The name of the servlet context.
*
* An array of the names the corresponding
* {@link org.osgi.service.http.context.ServletContextHelper} is used for.
*/
- public String[] names;
+ public String name;
/**
* The context name of the servlet context.
@@ -54,9 +55,10 @@ public class ServletContextDTO extends DTO {
public String contextPath;
/**
- * The servlet context initialization parameters. This is the set of parameters
- * provided when registering this context. Additional parameters like the Http Service Runtime
- * attributes are not included.
+ * The servlet context initialization parameters. This is the set of
+ * parameters provided when registering this context. Additional parameters
+ * like the Http Service Runtime attributes are not included. If the context
+ * has no initialization parameters, this map is empty.
*/
public Map<String, String> initParams;
@@ -64,19 +66,22 @@ public class ServletContextDTO extends DTO {
* The servlet context attributes.
*
* <p>
- * The value type must be a numerical type, Boolean, String, DTO or an array
- * of any of the former. Therefore this method will only return the
- * attributes of the servlet context conforming to this constraint.
+ * The value type must be a numerical type, {@code Boolean}, {@code String},
+ * {@code DTO} or an array of any of the former. Therefore this method will
+ * only return the attributes of the servlet context conforming to this
+ * constraint. Other attributes are omitted. If there are no attributes
+ * conforming to the constraint, an empty map is returned.
*/
public Map<String, Object> attributes;
/**
- * Service property identifying the servlet context. In the case of a servlet context registered
- * in the service registry and picked up by a whiteboard implementation, this value
- * is not negative and corresponds to the service id in the registry.
- * If the servlet context has not been registered in the service registry, the value
- * is negative and a unique negative value is generated by the Http Service Runtime
- * in this case.
+ * Service property identifying the servlet context. In the case of a
+ * servlet context backed by a {@code ServletContextHelper} registered in
+ * the service registry and picked up by a Http Whiteboard Implementation,
+ * this value is not negative and corresponds to the service id in the
+ * registry. If the servlet context is not backed by a service registered in
+ * the service registry, the value is negative and a unique negative value
+ * is generated by the Http Service Runtime in this case.
*/
public long serviceId;
@@ -29,12 +30,12 @@ import org.osgi.dto.DTO;
*
- * An array of the names the corresponding
- * {@link org.osgi.service.http.context.ServletContextHelper} is used for.
+ * The name of the corresponding
+ * {@link org.osgi.service.http.context.ServletContextHelper}.
*/

Back to the top